projectal.enums API documentation

# projectal.enums

Enums use readable names for string values expected by the Projectal API.

    # Example usage
    from projectal.enums import ConstraintType

    task = projectal.Task.create(project, {
        'name': 'Example Task',
        'constraintType': ConstraintType.ASAP,
        'taskType': TaskType.Task
    })

View Source

      1"""
      2Enums use readable names for string values expected by the Projectal
      3API.
      4
      5```
      6# Example usage
      7from projectal.enums import ConstraintType
      8
      9task = projectal.Task.create(project, {
     10    'name': 'Example Task',
     11    'constraintType': ConstraintType.ASAP,
     12    'taskType': TaskType.Task
     13})
     14```
     15"""
     16
     17class Currency:
     18    USD = "USD"
     19    AUD = "AUD"
     20    EUR = "EUR"
     21    PLN = "PLN"
     22    MYR = "MYR"
     23    INR = "INR"
     24    IRR = "IRR"
     25    JPY = "JPY"
     26    GBP = "GBP"
     27    CAD = "CAD"
     28    CHF = "CHF"
     29    CNY = "CNY"
     30    HKD = "HKD"
     31    NZD = "NZD"
     32    SEK = "SEK"
     33    KRW = "KRW"
     34    SGD = "SGD"
     35    NOK = "NOK"
     36    MXN = "MXN"
     37    RUB = "RUB"
     38    ZAR = "ZAR"
     39    TRY = "TRY"
     40    BRL = "BRL"
     41
     42
     43class TaskType:
     44    Project = "Project"
     45    Task = "Task"
     46    Milestone = "Milestone"
     47
     48
     49class ConstraintType:
     50    ASAP = "As_soon_as_possible"
     51    ALAP = "As_late_as_possible"
     52    SNET = "Start_no_earlier_than"
     53    SNLT = "Start_no_later_than"
     54    FNET = "Finish_no_earlier_than"
     55    FNLT = "Finish_no_later_than"
     56    MSO = "Must_start_on"
     57    MFO = "Must_finish_on"
     58
     59
     60class StaffType:
     61    Casual = "Casual"
     62    Contractor = "Contractor"
     63    Consultant = "Consultant"
     64    Freelance = "Freelance"
     65    Intern = "Intern"
     66    FullTime = "Full_Time"
     67    PartTime = "Part_Time"
     68
     69
     70class PayFrequency:
     71    # OneShot = "One_shot"
     72    Annually = "Annually"
     73    Monthly = "Monthly"
     74    Hourly = "Hourly"
     75    Daily = "Daily"
     76    Weekly = "Weekly"
     77
     78
     79class DateLimit:
     80    Min = "1970-01-01"
     81    Max = "9999-12-31"
     82
     83
     84class CompanyType:
     85    Primary = "Primary"
     86    Subsidiary = "Subsidiary"
     87    Contractor = "Contractor"
     88    Partner = "Partner"
     89    Affiliate = "Affiliate"
     90    Office = "Office"
     91
     92
     93class CalendarType:
     94    Leave = "Leave"
     95    Sunday = "Sunday"
     96    Monday = "Monday"
     97    Tuesday = "Tuesday"
     98    Wednesday = "Wednesday"
     99    Thursday = "Thursday"
    100    Friday = "Friday"
    101    Saturday = "Saturday"
    102    Working = "Working"
    103
    104
    105class SkillLevel:
    106    Junior = "Junior"
    107    Mid = "Mid"
    108    Senior = "Senior"
    109
    110
    111class GanttLinkType:
    112    FinishToStart = "Finish_to_start"
    113    StartToStart = "Start_to_start"
    114    FinishToFinish = "Finish_to_finish"
    115    StartToFinish = "Start_to_finish"

class Currency: View Source

    18class Currency:
    19    USD = "USD"
    20    AUD = "AUD"
    21    EUR = "EUR"
    22    PLN = "PLN"
    23    MYR = "MYR"
    24    INR = "INR"
    25    IRR = "IRR"
    26    JPY = "JPY"
    27    GBP = "GBP"
    28    CAD = "CAD"
    29    CHF = "CHF"
    30    CNY = "CNY"
    31    HKD = "HKD"
    32    NZD = "NZD"
    33    SEK = "SEK"
    34    KRW = "KRW"
    35    SGD = "SGD"
    36    NOK = "NOK"
    37    MXN = "MXN"
    38    RUB = "RUB"
    39    ZAR = "ZAR"
    40    TRY = "TRY"
    41    BRL = "BRL"

Currency()
class TaskType: View Source

    44class TaskType:
    45    Project = "Project"
    46    Task = "Task"
    47    Milestone = "Milestone"

TaskType()
class ConstraintType: View Source

    50class ConstraintType:
    51    ASAP = "As_soon_as_possible"
    52    ALAP = "As_late_as_possible"
    53    SNET = "Start_no_earlier_than"
    54    SNLT = "Start_no_later_than"
    55    FNET = "Finish_no_earlier_than"
    56    FNLT = "Finish_no_later_than"
    57    MSO = "Must_start_on"
    58    MFO = "Must_finish_on"

ConstraintType()
class StaffType: View Source

    61class StaffType:
    62    Casual = "Casual"
    63    Contractor = "Contractor"
    64    Consultant = "Consultant"
    65    Freelance = "Freelance"
    66    Intern = "Intern"
    67    FullTime = "Full_Time"
    68    PartTime = "Part_Time"

StaffType()
class PayFrequency: View Source

    71class PayFrequency:
    72    # OneShot = "One_shot"
    73    Annually = "Annually"
    74    Monthly = "Monthly"
    75    Hourly = "Hourly"
    76    Daily = "Daily"
    77    Weekly = "Weekly"

PayFrequency()
class DateLimit: View Source

    80class DateLimit:
    81    Min = "1970-01-01"
    82    Max = "9999-12-31"

DateLimit()
class CompanyType: View Source

    85class CompanyType:
    86    Primary = "Primary"
    87    Subsidiary = "Subsidiary"
    88    Contractor = "Contractor"
    89    Partner = "Partner"
    90    Affiliate = "Affiliate"
    91    Office = "Office"

CompanyType()
class CalendarType: View Source

     94class CalendarType:
     95    Leave = "Leave"
     96    Sunday = "Sunday"
     97    Monday = "Monday"
     98    Tuesday = "Tuesday"
     99    Wednesday = "Wednesday"
    100    Thursday = "Thursday"
    101    Friday = "Friday"
    102    Saturday = "Saturday"
    103    Working = "Working"

CalendarType()
class SkillLevel: View Source

    106class SkillLevel:
    107    Junior = "Junior"
    108    Mid = "Mid"
    109    Senior = "Senior"

SkillLevel()
class GanttLinkType: View Source

    112class GanttLinkType:
    113    FinishToStart = "Finish_to_start"
    114    StartToStart = "Start_to_start"
    115    FinishToFinish = "Finish_to_finish"
    116    StartToFinish = "Start_to_finish"

GanttLinkType()